@@ -19,8 +19,9 @@ Usage::
     ```
 """
 from datetime import datetime
-from typing import Iterator, Union
+from typing import Generic, Iterator, TypeVar, Union
 
+from botocore.paginate import PageIterator
 from botocore.paginate import Paginator as Boto3Paginator
 
 from .literals import SortOrderType
@@ -29,9 +30,19 @@ from .type_defs import ListHumanLoopsResponseTypeDef, PaginatorConfigTypeDef
 __all__ = ("ListHumanLoopsPaginator",)
 
 
+_ItemTypeDef = TypeVar("_ItemTypeDef")
+
+
+class _PageIterator(Generic[_ItemTypeDef], PageIterator):
+    def __iter__(self) -> Iterator[_ItemTypeDef]:
+        """
+        Proxy method to specify iterator item type.
+        """
+
+
 class ListHumanLoopsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.31/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Paginator.ListHumanLoops)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.32/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Paginator.ListHumanLoops)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sagemaker_a2i_runtime/paginators.html#listhumanloopspaginator)
     """
 
@@ -43,8 +54,8 @@ class ListHumanLoopsPaginator(Boto3Paginator):
         CreationTimeBefore: Union[datetime, str] = None,
         SortOrder: SortOrderType = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListHumanLoopsResponseTypeDef]:
+    ) -> _PageIterator[ListHumanLoopsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.31/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Paginator.ListHumanLoops.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.32/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Paginator.ListHumanLoops.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sagemaker_a2i_runtime/paginators.html#listhumanloopspaginator)
         """
